@@ -319,7 +319,7 @@ class ChangeFolderColor(ChangeFolderColorBase, GObject.GObject, Nemo.MenuProvide
         if not directories_selected:
             return
 
-        icon_theme_name = Gio.Settings.new("org.cinnamon.desktop.interface").get_string("icon-theme")
+        icon_theme_name = Gtk.Settings.get_default().get_property("gtk-icon-theme-name")
         if icon_theme_name in self.styles:
             icon_themes = self.styles[icon_theme_name]["icon-themes"]
             locale.setlocale(locale.LC_ALL, '')
